/*
 * Copyright (C) 2017 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blendb.
 *
 * blendb is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blendb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blendb.  If not, see <http://www.gnu.org/licenses/>.
 */

import * as request from "supertest";
import { expect } from "chai";

import * as server from "../../main";

describe("API error middleware", () => {

    it("should respond 404 when a route does not exists", (done) => {
        request(server)
            .get("/v1/inexistent")
            .expect(404)
            .expect((res: any) => {
                const error = "Cannot GET /v1/inexistent";
                expect(res.body).to.be.an("object");
                expect(res.body).to.have.property("error");
                expect(res.body.error).to.be.eql(error);
            })
            .end(done);
    });

    it("should respond 400 for missing required parameters", (done) => {
        request(server)
            .get("/v1/data")
            .query({metrics: "random"})
            .expect(400)
            .expect((res: any) => {
                const error = "Bad request: Some problems with this request were found";
                expect(res.body).to.be.an("object");
                expect(res.body).to.have.property("error");
                expect(res.body).to.have.property("requestErrors");
                expect(res.body.error).to.be.eql(error);
                expect(res.body.requestErrors).to.have.length(1);
            })
            .end(done);
    });
    it("should respond 400 when you connect, and do not send data", (done) => {
        request(server)
            .post("/v1/collect/Seller")
            .expect(400)
            .expect((res: any) => {
                expect(res.body).to.be.an("object");
                expect(res.body).to.have.property("error");
            })
            .end(done);    
    });
});
